@@ -4,7 +4,7 @@
 # PURPOSE:	Perform currency calculations without floating point
 #
 #------------------------------------------------------------------------------
-#   Copyright (c) 2000 John Peacock
+#   Copyright (c) 2001 John Peacock
 #
 #   You may distribute under the terms of either the GNU General Public
 #   License or the Artistic License, as specified in the Perl README file,
@@ -17,13 +17,15 @@ eval 'exec /usr2/local/bin/perl -S $0 ${1+"$@"}'
 package Math::Currency;
 
 use strict;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $PACKAGE $CLASSDATA);
+use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $PACKAGE $CLASSDATA
+	    $accuracy $precision $div_scale $round_mode);
 use Exporter;
-use Math::FixedPrecision(0.11);
-use overload	'""'	=>	\&stringify;
+use Math::BigFloat 1.27;
+use overload	'""'	=>	\&bstr,
+	;
 use POSIX qw(locale_h);
 
-@ISA = qw(Exporter Math::FixedPrecision);
+@ISA = qw(Exporter Math::BigFloat);
 # Items to export into callers namespace by default. Note: do not export
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
@@ -34,14 +36,14 @@ use POSIX qw(locale_h);
 	Money
 );
 
-$VERSION = '0.11';
+$VERSION = qw$Revision: 2.0 $[1]/10;
 
 $PACKAGE = 'Math::Currency';
 
 $CLASSDATA = {
 		SEPARATOR	=>	${localeconv()}{'mon_thousands_sep'} || ',',
 		DECIMAL		=>	${localeconv()}{'mon_decimal_point'} || '.',
-		FRAC_DIGITS =>	${localeconv()}{'frac_digits'} || '2',
+		FRAC_DIGITS 	=>	${localeconv()}{'frac_digits'} || '2',
 		GROUPING	=>	defined ${localeconv()}{'mon_grouping'} &&
 						unpack("C*",${localeconv()}{'mon_grouping'}) || '3',
 };
@@ -50,23 +52,17 @@ if ( defined ${localeconv()}{'p_cs_precedes'} and ${localeconv()}{'p_cs_precedes
 	$CLASSDATA->{PREFIX}	= '';
 	$CLASSDATA->{POSTFIX}	= ${localeconv()}{'currency_symbol'} || '$';
 }
-else 
+else
 {
 	$CLASSDATA->{PREFIX}	= ${localeconv()}{'currency_symbol'} || '$';
 	$CLASSDATA->{POSTFIX}	= '';
 }
-#	currency_symbol      = $
-#   frac_digits          = 2
-#	mon_decimal_point    = .
-#	mon_grouping         = 3 (get with unpack "C*" $locale_values->{'mon_grouping})
-#	mon_thousands_sep    = ,
-#	n_cs_precedes        = 1
-#	n_sep_by_space       = 0
-#	n_sign_posn          = 0
-#	negative_sign        = -
-#	p_cs_precedes        = 1
-#	p_sep_by_space       = 0
-#	p_sign_posn          = 3
+
+# Set class constants
+$round_mode = 'even';  # Banker's rounding obviously
+$accuracy   = undef;
+$precision  = -$CLASSDATA->{FRAC_DIGITS};
+$div_scale  = 40;
 
 
 # Preloaded methods go here.
@@ -77,7 +73,7 @@ sub new		#05/10/99 3:13:PM
 {
 	my $proto  = shift;
 	my $class  = ref($proto) || $proto;
-	my $parent = ref($proto) && $proto;
+	my $parent = $proto if ref($proto);
 
 	my $value = shift;
 	$value =~ tr/-0-9.//cd;	#strip any formatting characters
@@ -85,19 +81,21 @@ sub new		#05/10/99 3:13:PM
 	my $format = shift;
 	if ( $format )
 	{
-		$self = Math::FixedPrecision->new($value,$format->{FRAC_DIGITS});
+		$self = Math::BigFloat->new($value,undef,
+			-$format->{FRAC_DIGITS});
 		bless $self, $class;
 		$self->format($format);
 	}
 	elsif ( $parent and $parent->format )	# if we are cloning an existing instance
 	{
-		$self = Math::FixedPrecision->new($value,$parent->format->{FRAC_DIGITS}); # = bless {}, $class
+		$self = Math::BigFloat->new($value, undef,
+			-$parent->format->{FRAC_DIGITS});
 		bless $self, $class;
 		$self->format($parent->format);
 	}
-	else 
+	else
 	{
-		$self = Math::FixedPrecision->new($value,$CLASSDATA->{FRAC_DIGITS}); # = bless {}, $class
+		$self = Math::BigFloat->new($value);
 		bless $self, $class;
 	}
 	return $self;
@@ -110,7 +108,7 @@ sub _new		#07/28/00 4:50:PM
 {
 	my $proto  = shift;
 	my $class  = ref($proto) || $proto;
-	my $parent = ref($proto) && $proto;
+	my $parent = $proto if ref($proto);
 
 	my $value = shift;
 	$value =~ tr/-0-9.//cd;	#strip any formatting characters
@@ -118,13 +116,14 @@ sub _new		#07/28/00 4:50:PM
 	my $dp = shift;
 	if ( $parent and $parent->format )	# if we are cloning an existing instance
 	{
-		$self = Math::FixedPrecision->new($value,$parent->format->{FRAC_DIGITS}); # = bless {}, $class
+		$self = Math::BigFloat->new($value,undef,
+			-$parent->format->{FRAC_DIGITS});
 		bless $self, $class;
 		$self->format($parent->format);
 	}
-	else 
+	else
 	{
-		$self = Math::FixedPrecision->new($value,$CLASSDATA->{FRAC_DIGITS}); # = bless {}, $class
+		$self = Math::BigFloat->new($value);
 		bless $self, $class;
 	}
 	return $self;
@@ -139,17 +138,20 @@ sub Money		#05/10/99 4:16:PM
 }	##Money
 
 ############################################################################
-sub stringify		#05/10/99 3:52:PM
+sub bstr		#05/10/99 3:52:PM
 ############################################################################
 
 {
 	my $self  = shift;
-	my $value = abs($self->{VAL}) + 0;
-	my $neg   = $self->{VAL} < 0 ? 1 : 0; 
+	my $value = abs(Math::BigFloat::bstr($self));
+	my $neg   = $self->is_negative();
 	my $dp = length($value) - index($value, ".") - 1;
-	$value .= "0" x ( ${$self->format}{FRAC_DIGITS} - $dp ) if $dp < ${$self->format}{FRAC_DIGITS};
+	$value .= "0" x ( ${$self->format}{FRAC_DIGITS} - $dp )
+		if $dp < ${$self->format}{FRAC_DIGITS};
 	($value = reverse "$value") =~ s/\+//;
-	if ( substr($value,-1,1) eq '.' )	# make sure there is a leading 0 for values < 1
+
+	# make sure there is a leading 0 for values < 1
+	if ( substr($value,-1,1) eq '.' )
 	{
 		$value .= "0";
 	}
@@ -185,7 +187,7 @@ sub format		#05/17/99 1:58:PM
 	{
 		return $self->{format};
 	}
-	else 
+	else
 	{
 		return $CLASSDATA;
 	}
@@ -208,7 +210,7 @@ sub FRAC_DIGITS		#6/12/2000 3:28PM
 	{
 		return "${$self->format}{FRAC_DIGITS}";
 	}
-	else 
+	else
 	{
 		return "$CLASSDATA->{FRAC_DIGITS}";
 	}
@@ -231,7 +233,7 @@ sub POSTFIX		#6/12/2000 3:28PM
 	{
 		return "${$self->format}{POSTFIX}";
 	}
-	else 
+	else
 	{
 		return "$CLASSDATA->{POSTFIX}";
 	}
@@ -254,7 +256,7 @@ sub PREFIX		#6/12/2000 3:28PM
 	{
 		return "${$self->format}{PREFIX}";
 	}
-	else 
+	else
 	{
 		return "$CLASSDATA->{PREFIX}";
 	}
@@ -277,7 +279,7 @@ sub SEPARATOR		#6/12/2000 3:28PM
 	{
 		return "${$self->format}{SEPARATOR}";
 	}
-	else 
+	else
 	{
 		return "$CLASSDATA->{SEPARATOR}";
 	}
@@ -300,7 +302,7 @@ sub DECIMAL		#6/12/2000 3:28PM
 	{
 		return "${$self->format}{DECIMAL}";
 	}
-	else 
+	else
 	{
 		return "$CLASSDATA->{DECIMAL}";
 	}
@@ -323,7 +325,7 @@ sub GROUPING		#6/12/2000 3:28PM
 	{
 		return "${$self->format}{GROUPING}";
 	}
-	else 
+	else
 	{
 		return "$CLASSDATA->{GROUPING}";
 	}
@@ -343,8 +345,9 @@ Math::Currency - Exact Currency Math with Formatting and Rounding
   use Math::Currency qw(Money);
   $dollar = Math::Currency->new("$12,345.67");
   $taxamt = $dollar * 0.28;
+  # this sets the default format for all objects w/o their own format
   Math::Currency->format(
-	{ 
+	{
 		PREFIX      =>     '',
 		SEPARATOR   =>    ' ',
 		DECIMAL     =>    ',',
@@ -353,9 +356,9 @@ Math::Currency - Exact Currency Math with Formatting and Rounding
 		GROUPING    =>      3,
 	});
   $deutschmark = Money(12345.67);
-  $deutschmark_string = Money(12345.67)->stringify();
+  $deutschmark_string = Money(12345.67)->bstr();
   # or if you already have a Math::Currency object
-  $deutschmark_string = "$deutschmark"; 
+  $deutschmark_string = "$deutschmark";
 
 =head1 DESCRIPTION
 
@@ -365,19 +368,18 @@ allowed and division/multiplication should never create more accuracy than the
 original values.  All currency values should round to the closest cent or
 whatever the local equivalent should happen to be.
 
-Each currency value can have an individual format or the global currency 
-format can be changed to reflect local usage.  I used the suggestions in Tom 
+Each currency value can have an individual format or the global currency
+format can be changed to reflect local usage.  I used the suggestions in Tom
 Christiansen's L<PerlTootC|http://www.perl.com/language/misc/perltootc.html#Translucent_Attributes>
-to implement translucent attributes.  If you have set your locale values 
-correctly, this module will pick up your local settings or US standards if you 
+to implement translucent attributes.  If you have set your locale values
+correctly, this module will pick up your local settings or US standards if you
 haven't.
 
 All common mathematical operations are overloaded, so once you initialize a
 currency variable, you can treat it like any number and the module will do
-the right thing.  This module is a thin layer over Math::FixedPrecision which
-is itself a layer over Math::BigFloat which is itself a layer over Math::BigInt.
-The module optionally exports a single function Money() which can be used
-instead of Math::Currency->new().																		  
+the right thing.  This module is a thin layer over Math::BigFloat which
+is itself a layer over Math::BigInt.  The module optionally exports a single
+function Money() which can be used instead of Math::Currency->new().
 
 =head1 AUTHOR
 
@@ -387,6 +389,6 @@ John Peacock <jpeacock@rowman.com>
 
 perl(1).
 perllocale
-Math::FixedPrecision
+Math::BigFloat
 
-=cut
\ No newline at end of file
+=cut
